<?php
/**
 * Persian language file
 *
 * @author behrad eslamifar <behrad_es@yahoo.com)
 * @author Mohsen Firoozmandan <info@mambolearn.com>
 * @author omidmr@gmail.com
 * @author Omid Mottaghi <omidmr@gmail.com>
 * @author Mohammad Reza Shoaei <shoaei@gmail.com>
 */
$lang['menu']                  = 'تنظیمات پیکر‌بندی';
$lang['error']                 = 'به دلیل ایراد در مقادیر وارد شده، تنظیمات اعمال نشد، خواهشمندیم تغییرات را مجددن کنترل نمایید و دوباره ارسال کنید.<br/> مقادیر مشکل‌دار با کادر قرمز مشخص شده‌اند.';
$lang['updated']               = 'تنظیمات با موفقیت به روز رسانی شد.';
$lang['nochoice']              = '(گزینه‌های دیگری موجود نیست)';
$lang['locked']                = 'تنظیمات قابلیت به روز رسانی ندارند، اگر نباید چنین باشد، <br/> نام فایل تنظیمات و دسترسی‌های آن را بررسی کنید.';
$lang['danger']                = 'خطر: ممکن است با تغییر این گزینه دسترسی به منوی تنظیمات قطع شود.';
$lang['warning']               = 'هشدار: ممکن است با تغییر این گزینه رفتارهای غیرمترقبه‌ای مشاهده کنید.';
$lang['security']              = 'هشدار امنیتی: تغییر این گزینه ممکن است با خطرات امنیتی همراه باشد.';
$lang['_configuration_manager'] = 'مدیریت تنظیمات';
$lang['_header_dokuwiki']      = 'تنظیمات DokuWiki';
$lang['_header_plugin']        = 'تنظیمات افزونه';
$lang['_header_template']      = 'تنظیمات قالب';
$lang['_header_undefined']     = 'تنظیمات تعریف نشده';
$lang['_basic']                = 'تنظیمات مقدماتی';
$lang['_display']              = 'تنظیمات نمایش';
$lang['_authentication']       = 'تنظیمات معتبرسازی';
$lang['_anti_spam']            = 'تنظیمات ضد-اسپم';
$lang['_editing']              = 'تنظیمات ویرایش';
$lang['_links']                = 'تنظیمات پیوند';
$lang['_media']                = 'تنظیمات رسانه‌ها (فایل‌ها)';
$lang['_advanced']             = 'تنظیمات پیشرفته';
$lang['_network']              = 'تنظیمات شبکه';
$lang['_plugin_sufix']         = 'تنظیمات افزونه';
$lang['_template_sufix']       = 'تنظیمات قالب';
$lang['_msg_setting_undefined'] = 'داده‌نمایی برای تنظیمات وجود ندارد';
$lang['_msg_setting_no_class'] = 'هیچ دسته‌ای برای تنظیمات وجود ندارد.';
$lang['_msg_setting_no_default'] = 'بدون مقدار پیش‌فرض';
$lang['fmode']                 = 'دسترسی پیش‌فرض فایل‌ها در زمان ایجاد';
$lang['dmode']                 = 'زبان';
$lang['lang']                  = 'زبان';
$lang['basedir']               = 'شاخه‌ی اصلی';
$lang['baseurl']               = 'آدرس اصلی';
$lang['savedir']               = 'شاخه‌ی ذخیره‌سازی داده‌ها';
$lang['start']                 = 'نام صفحه‌ی آغازین';
$lang['title']                 = 'عنوان ویکی';
$lang['template']              = 'قالب';
$lang['license']               = 'لایسنس مطالب ویکی';
$lang['fullpath']              = 'نمایش دادن مسیر کامل صفحات در پایین صفحه';
$lang['recent']                = 'تغییرات اخیر';
$lang['breadcrumbs']           = 'تعداد ردپاها';
$lang['youarehere']            = 'ردپای درختی';
$lang['typography']            = 'جای‌گزاری متن‌ها انجام شود';
$lang['htmlok']                = 'امکان افزودن HTML باشد';
$lang['phpok']                 = 'امکان افزودن PHP باشد';
$lang['dformat']               = 'فرمت تاریخ (راهنمای تابع <a href="http://www.php.net/strftime">strftime</a> را مشاهده کنید)';
$lang['signature']             = 'امضا';
$lang['toptoclevel']           = 'بیشترین عمق برای «فهرست مطالب»';
$lang['tocminheads']           = 'حداقل مقدار عنوان‌های یک صفحه، برای تشخیص این‌که «فهرست مطالب» (TOC) ایجاد شود';
$lang['maxtoclevel']           = 'حداکثر عمق «فهرست مطالب»';
$lang['maxseclevel']           = 'بیش‌ترین سطح ویرایش بخش‌ها';
$lang['camelcase']             = 'از «حالت شتری» (CamelCase) برای پیوندها استفاده شود';
$lang['deaccent']              = 'تمیز کردن نام صفحات';
$lang['useheading']            = 'استفاده از اولین عنوان برای نام صفحه';
$lang['refcheck']              = 'بررسی کردن مرجع رسانه‌ها';
$lang['refshow']               = 'تعداد مراجعی که برای یک رسانه نمایش داده شود';
$lang['allowdebug']            = 'امکان کرم‌زدایی (debug) <b>اگر نیازی ندارید، غیرفعال کنید</b>';
$lang['usewordblock']          = 'اسپم‌ها را براساس لیست کلمات مسدود کن';
$lang['indexdelay']            = 'مقدار تاخیر پیش از فهرست‌بندی (ثانیه)';
$lang['relnofollow']           = 'از «rel=nofollow» در پیوندهای خروجی استفاده شود';
$lang['mailguard']             = 'مبهم کردن آدرس‌های ایمیل';
$lang['iexssprotect']          = 'بررسی کردن فایل‌های ارسال شده را برای کدهای HTML یا JavaScript مخرب';
$lang['showuseras']            = 'چگونه آخرین کاربر ویرایش کننده، یک صفحه نمایش داده شود';
$lang['useacl']                = 'استفاده از مدیریت دسترسی‌ها';
$lang['autopasswd']            = 'ایجاد خودکار گذرواژه‌ها';
$lang['authtype']              = 'روش معتبرسازی';
$lang['passcrypt']             = 'روش کد کردن گذرواژه';
$lang['defaultgroup']          = 'گروه پیش‌فرض';
$lang['superuser']             = 'کاربر اصلی - گروه، کاربر یا لیستی که توسط ویرگول جدا شده از کاربرها و گروه‌ها (مثل user1,@group1,user2) با دسترسی کامل به همه‌ی صفحات و امکانات سیستم، فارغ از دسترسی‌های آن کاربر.';
$lang['manager']               = 'مدیر - گروه، کاربر یا لیستی که توسط ویرگول جدا شده از کاربرها و گروه‌ها (مثل user1,@group1,user2) با دسترسی‌های خاص به بخش‌های متفاوت';
$lang['profileconfirm']        = 'تغییرات پروفایل با وارد کردن گذرواژه تایید شود';
$lang['disableactions']        = 'غیرفعال کردن فعالیت‌های DokuWiki';
$lang['disableactions_check']  = 'بررسی';
$lang['disableactions_subscription'] = 'عضویت/عدم عضویت';
$lang['disableactions_wikicode'] = 'نمایش سورس/برون‌بری خام';
$lang['disableactions_other']  = 'فعالیت‌های دیگر (با ویرگول انگلیسی «,» از هم جدا کنید)';
$lang['sneaky_index']          = 'به طور پیش‌فرض، DokuWiki در فهرست تمامی فضای‌نام‌ها را نمایش می‌دهد. فعال کردن این گزینه، مواردی را که کاربر حق خواندنشان را ندارد مخفی می‌کند. این گزینه ممکن است باعث دیده نشدن زیرفضای‌نام‌هایی شود که دسترسی خواندن به آن‌ها وجود دارد. و ممکن است باعث شود که فهرست در حالاتی از دسترسی‌ها، غیرقابل استفاده شود.';
$lang['auth_security_timeout'] = 'زمان انقضای معتبرسازی به ثانیه';
$lang['securecookie']          = 'آیا کوکی‌ها باید با قرارداد HTTPS ارسال شوند؟ این گزینه را زمانی که فقط صفحه‌ی ورود ویکی‌تان با SSL امن شده است، اما ویکی را ناامن مرور می‌کنید، غیرفعال نمایید.';
$lang['xmlrpc']                = 'فعال/غیرفعال کردن XML-RPC';
$lang['xmlrpcuser']            = 'محمدود کردن دسترسی به XML-RPC توسط گروه های جدا شده توسط ویرگول ویا اعضای داده شده در اینجا. این مکان را خالی بگزارید تا به همه دسترسی داده شود.';
$lang['updatecheck']           = 'هشدارهای به روز رسانی و امنیتی بررسی شود؟ برای این‌کار DokuWiki با سرور update.dokuwiki.org تماس خواهد گرفت.';
$lang['userewrite']            = 'از زیباکننده‌ی آدرس‌ها استفاده شود';
$lang['useslash']              = 'از اسلش «/» برای جداکننده‌ی آدرس فضای‌نام‌ها استفاده شود';
$lang['usedraft']              = 'ایجاد خودکار چرک‌نویس در زمان نگارش';
$lang['sepchar']               = 'کلمه‌ی جداکننده‌ی نام صفحات';
$lang['canonical']             = 'استفاده از آدرس‌های استاندارد';
$lang['fnencode']              = 'روش تغییر نام فایل‌هایی با فرمتی غیر از اسکی';
$lang['autoplural']            = 'بررسی جمع بودن در پیوندها';
$lang['compression']           = 'روش فشرده‌سازی برای فایل‌های خُرد';
$lang['cachetime']             = 'بیشینه‌ی زمان حافظه‌ی موقت (cache) به ثانیه';
$lang['locktime']              = 'بیشینه‌ی زمان قفل شدن فایل‌ها به ثانیه';
$lang['fetchsize']             = 'بیشینه‌ی حجمی که فایل fetch.php می‌تواند دریافت کند (به بایت)';
$lang['notify']                = 'تغییرات به این ایمیل ارسال شود';
$lang['registernotify']        = 'اطلاعات کاربران تازه وارد به این ایمیل ارسال شود';
$lang['mailfrom']              = 'آدرس ایمیلی که برای ایمیل‌های خودکار استفاده می‌شود';
$lang['mailprefix']            = 'پیشوند تیتر ایمیل (جهت ایمیل های خودکار)';
$lang['gzip_output']           = 'استفاده از gzip برای xhtmlها';
$lang['gdlib']                 = 'نگارش کتاب‌خانه‌ی GD';
$lang['im_convert']            = 'مسیر ابزار convert از برنامه‌ی ImageMagick';
$lang['jpg_quality']           = 'کیفیت فشرده سازی JPEG (از 0 تا 100)';
$lang['subscribers']           = 'توانایی عضویت در صفحات باشد';
$lang['subscribe_time']        = 'زمان مورد نیاز برای ارسال خبر نامه ها (ثانیه); این مقدار می بایست کمتر زمانی باشد که در recent_days تعریف شده است.';
$lang['compress']              = 'فشرده‌سازی کد‌های CSS و JavaScript';
$lang['hidepages']             = 'مخفی کردن صفحات با فرمت زیر (از عبارات منظم استفاده شود)';
$lang['send404']               = 'ارسال «HTTP 404/Page Not Found» برای صفحاتی که وجود ندارند';
$lang['sitemap']               = 'تولید کردن نقشه‌ی سایت توسط گوگل (روز)';
$lang['broken_iua']            = 'آیا تابع ignore_user_about در ویکی شما کار نمی‌کند؟ ممکن است فهرست جستجوی شما کار نکند. IIS به همراه PHP/CGI باعث خراب شدن این گزینه می‌شود. برای اطلاعات بیشتر <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">باگ ۸۵۲</a> را مشاهده کنید.';
$lang['xsendfile']             = 'استفاده از هدر X-Sendfile، تا به وب‌سرور  توانایی ارسال فایل‌های ثابت را بدهد. وب‌سرور شما باید این مورد را پشتیبانی کند.';
$lang['renderer_xhtml']        = 'مفسری که برای خروجی اصلی ویکی استفاده شود';
$lang['renderer__core']        = '%s (هسته‌ی dokuwiki)';
$lang['renderer__plugin']      = '%s (افزونه)';
$lang['rememberme']            = 'امکان ورود دایم، توسط کوکی، وجود داشته باشد (مرا به خاطر بسپار)';
$lang['rss_type']              = 'نوع خوراک';
$lang['rss_linkto']            = 'خوراک به کجا لینک شود';
$lang['rss_content']           = 'چه چیزی در تکه‌های خوراک نمایش داده شود؟';
$lang['rss_update']            = 'زمان به روز رسانی خوراک به ثانیه';
$lang['recent_days']           = 'چند تغییر در خوراک نمایش داده شود به روز';
$lang['rss_show_summary']      = 'خوراک مختصری از مطلب را در عنوان نمایش دهد';
$lang['target____wiki']        = 'پنجره‌ی هدف در پیوند‌های داخلی';
$lang['target____interwiki']   = 'پنجره‌ی هدف در پیوند‌های داخل ویکی';
$lang['target____extern']      = 'پنجره‌ی هدف در پیوند‌های خارجی';
$lang['target____media']       = 'پنجره‌ی هدف در پیوند‌های رسانه‌ها';
$lang['target____windows']     = 'پنجره‌ی هدف در پیوند‌های پنجره‌ای';
$lang['proxy____host']         = 'آدرس سرور پروکسی';
$lang['proxy____port']         = 'پورت پروکسی';
$lang['proxy____user']         = 'نام کاربری پروکسی';
$lang['proxy____pass']         = 'گذرواژهي پروکسی';
$lang['proxy____ssl']          = 'استفاده از SSL برای اتصال به پروکسی';
$lang['proxy____except']       = 'عبارت منظم برای تطبیق با URLها برای این‌که دریابیم که از روی  چه پروکسی‌ای باید بپریم!';
$lang['safemodehack']          = 'فعال کردن safemode hack';
$lang['ftp____host']           = 'آدرس FTP برای safemode hack';
$lang['ftp____port']           = 'پورت FTP برای safemode hack';
$lang['ftp____user']           = 'نام کاربری FTP برای safemode hack';
$lang['ftp____pass']           = 'گذرواژه‌ی FTP برای safemode hack';
$lang['ftp____root']           = 'شاخه‌ی FTP برای safemode hack';
$lang['license_o_']            = 'هیچ کدام';
$lang['typography_o_0']        = 'هیچ';
$lang['typography_o_1']        = 'حذف کردن single-quote';
$lang['typography_o_2']        = 'به همراه داشتن single-quote (ممکن است همیشه کار نکند)';
$lang['userewrite_o_0']        = 'هیچ';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'از طریق DokuWiki';
$lang['deaccent_o_0']          = 'خاموش';
$lang['deaccent_o_1']          = 'برداشتن تلفظ‌ها';
$lang['deaccent_o_2']          = 'لاتین کردن (romanize)';
$lang['gdlib_o_0']             = 'کتاب‌خانه‌ی GD موجود نیست';
$lang['gdlib_o_1']             = 'نسخه‌ی 1.X';
$lang['gdlib_o_2']             = 'انتخاب خودکار';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'انتزاعی';
$lang['rss_content_o_diff']    = 'یکی کردن تفاوت‌ها';
$lang['rss_content_o_htmldiff'] = 'جدول تفاوت‌ها با ساختار HTML';
$lang['rss_content_o_html']    = 'تمامی محتویات صفحه، با ساختار HTML';
$lang['rss_linkto_o_diff']     = 'نمایه‌های متفاوت';
$lang['rss_linkto_o_page']     = 'صفحه‌ی تجدید نظر شده';
$lang['rss_linkto_o_rev']      = 'لیست نگارش‌ها';
$lang['rss_linkto_o_current']  = 'صفحه‌ی کنونی';
$lang['compression_o_0']       = 'هیچ';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'استفاده نکنید';
$lang['xsendfile_o_1']         = 'هدر اختصاصی lighttpd (پیش از نگارش ۱.۵)';
$lang['xsendfile_o_2']         = 'هدر استاندارد X-Sendfile';
$lang['xsendfile_o_3']         = 'هدر اختصاصی X-Accel-Redirect در وب سرور Nginx';
$lang['showuseras_o_loginname'] = 'نام کاربری';
$lang['showuseras_o_username'] = 'نام کامل کاربران';
$lang['showuseras_o_email']    = 'آدرس ایمیل کاربران (با تنظیمات «نگهبان ایمیل» مبهم می‌شود)';
$lang['showuseras_o_email_link'] = 'نمایش ایمیل کاربران با افزودن mailto';
$lang['useheading_o_0']        = 'هرگز';
$lang['useheading_o_navigation'] = 'فقط ناوبری (navigation)';
$lang['useheading_o_content']  = 'فقط محتویات ویکی';
$lang['useheading_o_1']        = 'همیشه';
$lang['readdircache']          = 'بیش‌ترین عمر برای حافظه‌ی موقت readdir (ثانیه)';
